# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.notification.v1 import project_channel_pb2 as spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2


class ProjectChannelStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.notification.v1.ProjectChannel/create',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.CreateProjectChannelRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.notification.v1.ProjectChannel/update',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.UpdateProjectChannelRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.FromString,
                )
        self.set_schedule = channel.unary_unary(
                '/spaceone.api.notification.v1.ProjectChannel/set_schedule',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.UpdateProjectChannelScheduleRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.FromString,
                )
        self.set_subscription = channel.unary_unary(
                '/spaceone.api.notification.v1.ProjectChannel/set_subscription',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.UpdateProjectChannelSubscriptionRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.FromString,
                )
        self.enable = channel.unary_unary(
                '/spaceone.api.notification.v1.ProjectChannel/enable',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.FromString,
                )
        self.disable = channel.unary_unary(
                '/spaceone.api.notification.v1.ProjectChannel/disable',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.notification.v1.ProjectChannel/delete',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.notification.v1.ProjectChannel/get',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.GetProjectChannelRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.notification.v1.ProjectChannel/list',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.notification.v1.ProjectChannel/stat',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class ProjectChannelServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new ProjectChannel. ProjectChannel is a channel that delivers a Notification to the Project when the Notification is created. When creating a ProjectChannel, one Protocol must be selected, and a Notification is dispatched via the selected Protocol.
        request_example: >-
        {
        "protocol_id": "protocol-ab94ea7d574e",
        "name": "sms-test",
        "data": {
        "phone_number": "01011112222"
        },
        "is_subscribe": true,
        "subscriptions": ["monitoring.Alert"],
        "notification_level": "LV1",
        "is_scheduled": true,
        "schedule": {
        "day_of_week": [
        "MON",
        "TUE",
        "WED",
        "THU",
        "FRI"
        ],
        "end_hour": 9
        },
        "project_id": "project-52a423012d5e"
        }
        response_example: >-
        {
        "project_channel_id": "project-ch-488df94d026d",
        "name": "sms-test",
        "state": "ENABLED",
        "data": {
        "phone_number": "01011112222"
        },
        "notification_level": "LV1",
        "tags": {},
        "protocol_id": "protocol-ab94ea7d574e",
        "project_id": "project-aa723eed3d69",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-13T07:35:28.305Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific ProjectChannel. A ProjectChannel that has already been configured cannot be changed. Instead, the data required for dispatching Notifications to a ProjectChannel can be updated.
        request_example: >-
        {
        "project_channel_id": "project-ch-488df94d026d",
        "name": "sms2-test",
        "data": {
        "phone_number": "01033334444"
        },
        "notification_level": "LV2",
        "tags": {
        "a": "b"
        }
        }
        response_example: >-
        {
        "project_channel_id": "project-ch-488df94d026d",
        "name": "sms2-test",
        "state": "ENABLED",
        "data": {
        "phone_number": "01033334444"
        },
        "notification_level": "LV2",
        "tags": {
        "a": "b"
        },
        "protocol_id": "protocol-ab94ea7d574e",
        "project_id": "project-aa723eed3d69",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-13T07:35:28.305Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def set_schedule(self, request, context):
        """
        desc: Sets a schedule for a ProjectChannel. A schedule defines the time to receive a Notification. When a Notification is created, you can set the day of the week and time you want to receive it. When you set the day of the week, you can receive a notification only on the day of the week you set. If you also set the start time and end time with the day of the week, you can receive a Notification only at the scheduled time on the day of the week you set. If there is no schedule set in a ProjectChannel, Notifications will be dispatched at all times via the ProjectChannel.
        request_example: >-
        {
        "project_channel_id": "project-ch-488df94d026d",
        "is_scheduled": true,
        "schedule": {
        "day_of_week": [
        "MON",
        "WED",
        "FRI"
        ],
        "end_hour": 9
        }
        }
        response_example: >-
        {
        "project_channel_id": "project-ch-488df94d026d",
        "name": "sms2-test",
        "state": "ENABLED",
        "data": {
        "phone_number": "01033334444"
        },
        "notification_level": "LV2",
        "is_scheduled": true,
        "schedule": {
        "day_of_week": [
        "MON",
        "WED",
        "FRI"
        ],
        "end_hour": 9
        },
        "tags": {
        "a": "b"
        },
        "protocol_id": "protocol-ab94ea7d574e",
        "project_id": "project-aa723eed3d69",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-13T07:35:28.305Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def set_subscription(self, request, context):
        """
        desc: Sets a subscription for a ProjectChannel. A subscription is a topic for channels to subscribe to and get notified about. If a ProjectChannel has subscriptions, a Notification is dispatched only if the topic of the Notification is the same as the one set in the subscriptions. If there is no subscription in a ProjectChannel, all Notifications will be dispatched.
        request_example: >-
        {
        "project_channel_id": "project-ch-cff007433a23",
        "is_subscribe": true,
        "subscriptions": [
        "monitoring.Alert"
        ]
        }
        response_example: >-
        {
        "project_channel_id": "project-ch-cff007433a23",
        "name": "sms-test",
        "state": "ENABLED",
        "data": {
        "phone_number": "01033334444"
        },
        "is_subscribe": true,
        "subscriptions": [
        "monitoring.Alert"
        ],
        "notification_level": "LV1",
        "is_scheduled": true,
        "schedule": {
        "day_of_week": [
        "MON",
        "TUE",
        "WED",
        "THU",
        "FRI"
        ],
        "end_hour": 9
        },
        "tags": {},
        "protocol_id": "protocol-ab94ea7d574e",
        "project_id": "project-52a423012d5e",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-20T06:03:09.177Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def enable(self, request, context):
        """
        desc: Enables a specific ProjectChannel. If a ProjectChannel is enabled, the ProjectChannel can be used and the Notification can be dispatched. Even if a ProjectChannel is enabled, if the Protocol used in the ProjectChannel is disabled, the Notification is not dispatched.
        request_example: >-
        {
        "project_channel_id": "project-ch-ffdb1d6cc774"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def disable(self, request, context):
        """
        desc: Disables a specific ProjectChannel. If a ProjectChannel is disabled, the Notification is not dispatched, even if it is created.
        request_example: >-
        {
        "project_channel_id": "project-ch-ffdb1d6cc774"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific ProjectChannel.
        request_example: >-
        {
        "project_channel_id": "project-ch-ffdb1d6cc774"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific ProjectChannel. Prints detailed information about the ProjectChannel.
        request_example: >-
        {
        "project_channel_id": "project-ch-ffdb1d6cc774"
        }
        response_example: >-
        {
        "project_channel_id": "project-ch-ffdb1d6cc774",
        "name": "personal_email",
        "state": "ENABLED",
        "data": {
        "email": "user1@cloudforet.io"
        },
        "notification_level": "LV1",
        "tags": {},
        "protocol_id": "protocol-e000a677ebdb",
        "project_id": "project-52a423012d5e",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-20T04:40:21.264Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all ProjectChannels. You can use a query to get a filtered list of ProjectChannels.
        request_example: >-
        {
        "query": {
        "filter": [
        {
        "key": "state",
        "value": "ENABLED",
        "operator": "eq"
        }
        ]
        }
        }
        response_example: >-
        {
        "results": [
        {
        "project_channel_id": "project-ch-473efcfde4b1",
        "name": "Email Groups",
        "state": "ENABLED",
        "data": {
        "email": "sykim1@cloudforet.io, sykim2@cloudforet.io"
        },
        "notification_level": "LV1",
        "tags": {},
        "protocol_id": "protocol-e000a677ebdb",
        "project_id": "project-28cf4f2e6645",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-04-18T01:22:01.182Z"
        },
        {
        "project_channel_id": "project-ch-98845ba0f975",
        "name": "Song Email",
        "state": "ENABLED",
        "data": {
        "email": "sykim@mz.co.kr"
        },
        "notification_level": "LV1",
        "tags": {},
        "protocol_id": "protocol-e000a677ebdb",
        "project_id": "project-28cf4f2e6645",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-04-18T01:17:40.741Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectChannelServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.CreateProjectChannelRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.UpdateProjectChannelRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.SerializeToString,
            ),
            'set_schedule': grpc.unary_unary_rpc_method_handler(
                    servicer.set_schedule,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.UpdateProjectChannelScheduleRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.SerializeToString,
            ),
            'set_subscription': grpc.unary_unary_rpc_method_handler(
                    servicer.set_subscription,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.UpdateProjectChannelSubscriptionRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.SerializeToString,
            ),
            'enable': grpc.unary_unary_rpc_method_handler(
                    servicer.enable,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.SerializeToString,
            ),
            'disable': grpc.unary_unary_rpc_method_handler(
                    servicer.disable,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.GetProjectChannelRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.notification.v1.ProjectChannel', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProjectChannel(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.ProjectChannel/create',
            spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.CreateProjectChannelRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.ProjectChannel/update',
            spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.UpdateProjectChannelRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def set_schedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.ProjectChannel/set_schedule',
            spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.UpdateProjectChannelScheduleRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def set_subscription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.ProjectChannel/set_subscription',
            spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.UpdateProjectChannelSubscriptionRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def enable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.ProjectChannel/enable',
            spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def disable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.ProjectChannel/disable',
            spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.ProjectChannel/delete',
            spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.ProjectChannel/get',
            spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.GetProjectChannelRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.ProjectChannel/list',
            spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelQuery.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.ProjectChannel/stat',
            spaceone_dot_api_dot_notification_dot_v1_dot_project__channel__pb2.ProjectChannelStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.inventory.plugin import collector_pb2 as spaceone_dot_api_dot_inventory_dot_plugin_dot_collector__pb2


class CollectorStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.init = channel.unary_unary(
                '/spaceone.api.inventory.plugin.Collector/init',
                request_serializer=spaceone_dot_api_dot_inventory_dot_plugin_dot_collector__pb2.InitRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_plugin_dot_collector__pb2.PluginInfo.FromString,
                )
        self.verify = channel.unary_unary(
                '/spaceone.api.inventory.plugin.Collector/verify',
                request_serializer=spaceone_dot_api_dot_inventory_dot_plugin_dot_collector__pb2.VerifyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.collect = channel.unary_stream(
                '/spaceone.api.inventory.plugin.Collector/collect',
                request_serializer=spaceone_dot_api_dot_inventory_dot_plugin_dot_collector__pb2.CollectRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_plugin_dot_collector__pb2.ResourceInfo.FromString,
                )


class CollectorServicer(object):
    """Missing associated documentation comment in .proto file."""

    def init(self, request, context):
        """
        desc: Initializes a specific Collector. During initialization, the Collector information to be passed to the Collector user is delivered as `metadata`. Collector information includes its name and version.
        request_example: >-
        {

        }
        response_example: >-
        {

        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def verify(self, request, context):
        """
        desc: Verifies a specific Collector. You must specify the parameter `secret_data`, encrypted account data of the Collector to validate.
        request_example: >-
        {

        }
        response_example: >-
        {

        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def collect(self, request, context):
        """
        desc: Collects data of external infrastructure resources by a specific Collector.
        request_example: >-
        {

        }
        response_example: >-
        {

        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CollectorServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'init': grpc.unary_unary_rpc_method_handler(
                    servicer.init,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_plugin_dot_collector__pb2.InitRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_plugin_dot_collector__pb2.PluginInfo.SerializeToString,
            ),
            'verify': grpc.unary_unary_rpc_method_handler(
                    servicer.verify,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_plugin_dot_collector__pb2.VerifyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'collect': grpc.unary_stream_rpc_method_handler(
                    servicer.collect,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_plugin_dot_collector__pb2.CollectRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_plugin_dot_collector__pb2.ResourceInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.inventory.plugin.Collector', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Collector(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def init(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.plugin.Collector/init',
            spaceone_dot_api_dot_inventory_dot_plugin_dot_collector__pb2.InitRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_plugin_dot_collector__pb2.PluginInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def verify(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.plugin.Collector/verify',
            spaceone_dot_api_dot_inventory_dot_plugin_dot_collector__pb2.VerifyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def collect(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/spaceone.api.inventory.plugin.Collector/collect',
            spaceone_dot_api_dot_inventory_dot_plugin_dot_collector__pb2.CollectRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_plugin_dot_collector__pb2.ResourceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/sample/v1/helloworld.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/sample/v1/helloworld.proto\x12\x16spaceone.api.sample.v1\"\x1c\n\x0cHelloRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1d\n\nHelloReply\x12\x0f\n\x07message\x18\x01 \x01(\t2e\n\nHelloWorld\x12W\n\tsay_hello\x12$.spaceone.api.sample.v1.HelloRequest\x1a\".spaceone.api.sample.v1.HelloReply\"\x00\x62\x06proto3')



_HELLOREQUEST = DESCRIPTOR.message_types_by_name['HelloRequest']
_HELLOREPLY = DESCRIPTOR.message_types_by_name['HelloReply']
HelloRequest = _reflection.GeneratedProtocolMessageType('HelloRequest', (_message.Message,), {
  'DESCRIPTOR' : _HELLOREQUEST,
  '__module__' : 'spaceone.api.sample.v1.helloworld_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.sample.v1.HelloRequest)
  })
_sym_db.RegisterMessage(HelloRequest)

HelloReply = _reflection.GeneratedProtocolMessageType('HelloReply', (_message.Message,), {
  'DESCRIPTOR' : _HELLOREPLY,
  '__module__' : 'spaceone.api.sample.v1.helloworld_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.sample.v1.HelloReply)
  })
_sym_db.RegisterMessage(HelloReply)

_HELLOWORLD = DESCRIPTOR.services_by_name['HelloWorld']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _HELLOREQUEST._serialized_start=67
  _HELLOREQUEST._serialized_end=95
  _HELLOREPLY._serialized_start=97
  _HELLOREPLY._serialized_end=126
  _HELLOWORLD._serialized_start=128
  _HELLOWORLD._serialized_end=229
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.monitoring.v1 import webhook_pb2 as spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2


class WebhookStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Webhook/create',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.CreateWebhookRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Webhook/update',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.UpdateWebhookRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookInfo.FromString,
                )
        self.update_plugin = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Webhook/update_plugin',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.UpdateWebhookPluginRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookInfo.FromString,
                )
        self.verify_plugin = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Webhook/verify_plugin',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.enable = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Webhook/enable',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookInfo.FromString,
                )
        self.disable = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Webhook/disable',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Webhook/delete',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Webhook/get',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.GetWebhookRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Webhook/list',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhooksInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Webhook/stat',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class WebhookServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new Webhook. A Webhook collects data from an external monitoring system with a webhook URL generated by the resource.
        request_example: >-
        {
        "name": "aws-sns-webhook-for-phd",
        "plugin_info": {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "options": {}
        },
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "webhook_id": "webhook-123456789012",
        "name": "aws-sns-webhook-for-phd",
        "state": "ENABLED",
        "access_key": "1234567890123456789012345678901",
        "webhook_url": "https://spaceone.dev/monitoring/v1/webhook/webhook-123456789012/1234567890123456789012345678901/events",
        "capability": {},
        "plugin_info": {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "version": "1.2.2",
        "options": {},
        "metadata": {},
        "upgrade_mode": "AUTO"
        },
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T07:23:33.875Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific Webhook. You can make changes in Webhook settings, including the name and tags.
        request_example: >-
        {
        "webhook_id": "webhook-123456789012",
        "name": "aws-sns-webhook-for-cloudwatch",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "webhook_id": "webhook-123456789012",
        "name": "aws-sns-webhook-for-cloudwatch",
        "state": "ENABLED",
        "access_key": "1234567890123456789012345678901",
        "webhook_url": "https://spaceone.dev/monitoring/v1/webhook/webhook-123456789012/1234567890123456789012345678901/events",
        "capability": {},
        "plugin_info": {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "version": "1.2.2",
        "options": {},
        "metadata": {},
        "upgrade_mode": "AUTO"
        },
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T07:23:33.875Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_plugin(self, request, context):
        """
        desc: Updates the plugin of a specific DataSource. You can change the `version` of the plugin and select the `upgrade_mode` among `AUTO`, `MANUAL`, and `NONE`.
        request_example: >-
        {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "version": "1.2.2",
        "options": {},
        "metadata": {},
        "upgrade_mode": "AUTO"
        }
        response_example: >-
        {
        "webhook_id": "webhook-123456789012",
        "name": "AWS-SNS-Webhook",
        "state": "ENABLED",
        "access_key": "1234567890121234567890121234",
        "webhook_url": "https://monitoring-webhook.dev.spaceone.dev/monitoring/v1/webhook/webhook-123456789012/1234567890121234567890121234/events",
        "capability": {},
        "plugin_info": {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "version": "1.2.2",
        "options": {},
        "metadata": {},
        "upgrade_mode": "AUTO"
        },
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T09:13:16.723Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def verify_plugin(self, request, context):
        """
        desc: Verifies a specific plugin for a Webhook.
        request_example: >-
        {
        "webhook_id": "webhook-123456789012",
        "domain_id": "domain-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def enable(self, request, context):
        """
        desc: Enables a specific Webhook. By enabling a Webhook, you can communicate with an external application.
        request_example: >-
        {
        "webhook_id": "webhook-123456789012",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "webhook_id": "webhook-123456789012",
        "name": "aws-sns-webhook-for-cloudwatch",
        "state": "ENABLED",
        "access_key": "1234567890123456789012345678901",
        "webhook_url": "https://monitoring-webhook.dev.spaceone.dev/monitoring/v1/webhook/webhook-123456789012/1234567890123456789012345678901/events",
        "capability": {},
        "plugin_info": {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "version": "1.2.2",
        "options": {},
        "metadata": {},
        "upgrade_mode": "AUTO"
        },
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T07:23:33.875Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def disable(self, request, context):
        """
        desc: Disables a specific Webhook. By disabling a Webhook, you cannot communicate with an external application, as the webhook URL from the Webhook becomes invalid.
        request_example: >-
        {
        "webhook_id": "webhook-123456789012",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "webhook_id": "webhook-123456789012",
        "name": "aws-sns-webhook-for-cloudwatch",
        "state": "DISABLED",
        "access_key": "1234567890123456789012345678901",
        "webhook_url": "https://monitoring-webhook.dev.spaceone.dev/monitoring/v1/webhook/webhook-123456789012/1234567890123456789012345678901/events",
        "capability": {},
        "plugin_info": {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "version": "1.2.2",
        "options": {},
        "metadata": {},
        "upgrade_mode": "AUTO"
        },
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T07:23:33.875Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific Webhook. By deleting a Webhook, you cannot collect data from an external monitoring system, as the `REST URL` is also deleted.
        request_example: >-
        {
        "webhook_id": "webhook-123456789012",
        "domain_id": "domain-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Webhook. Prints detailed information about the Webhook, including the name, the version, and the created datetime.
        request_example: >-
        {
        "webhook_id": "webhook-123456789012",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "webhook_id": "webhook-123456789012",
        "name": "aws-sns-webhook-for-cloudwatch",
        "state": "ENABLED",
        "access_key": "1234567890123456789012345678901",
        "webhook_url": "https://monitoring-webhook.dev.spaceone.dev/monitoring/v1/webhook/webhook-123456789012/1234567890123456789012345678901/events",
        "capability": {},
        "plugin_info": {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "version": "1.2.2",
        "options": {},
        "metadata": {},
        "upgrade_mode": "AUTO"
        },
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T07:23:33.875Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Webhooks. You can use a query to get a filtered list of Webhooks.
        request_example: >-
        {
        "query": {},
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "results": [
        {
        "webhook_id": "webhook-123456789012",
        "name": "aws-sns-webhook-for-cloudwatch",
        "state": "ENABLED",
        "access_key": "1234567890123456789012345678901",
        "webhook_url": "https://monitoring-webhook.dev.spaceone.dev/monitoring/v1/webhook/webhook-123456789012/1234567890123456789012345678901/events",
        "capability": {},
        "plugin_info": {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "version": "1.2.2",
        "options": {},
        "metadata": {},
        "upgrade_mode": "AUTO"
        },
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T07:23:33.875Z"
        },
        {
        "webhook_id": "webhook-987654321098",
        "name": "zabbix-webhook",
        "state": "ENABLED",
        "access_key": "9876567890123456789012345678901",
        "webhook_url": "https://monitoring-webhook.dev.spaceone.dev/monitoring/v1/webhook/webhook-987654321098/9876567890123456789012345678901/events",
        "capability": {},
        "plugin_info": {
        "plugin_id": "plugin-zabbix-mon-webhook",
        "version": "1.0",
        "options": {},
        "metadata": {},
        "upgrade_mode": "AUTO"
        },
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T07:42:31.872Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WebhookServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.CreateWebhookRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.UpdateWebhookRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookInfo.SerializeToString,
            ),
            'update_plugin': grpc.unary_unary_rpc_method_handler(
                    servicer.update_plugin,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.UpdateWebhookPluginRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookInfo.SerializeToString,
            ),
            'verify_plugin': grpc.unary_unary_rpc_method_handler(
                    servicer.verify_plugin,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'enable': grpc.unary_unary_rpc_method_handler(
                    servicer.enable,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookInfo.SerializeToString,
            ),
            'disable': grpc.unary_unary_rpc_method_handler(
                    servicer.disable,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.GetWebhookRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhooksInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.monitoring.v1.Webhook', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Webhook(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Webhook/create',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.CreateWebhookRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Webhook/update',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.UpdateWebhookRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update_plugin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Webhook/update_plugin',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.UpdateWebhookPluginRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def verify_plugin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Webhook/verify_plugin',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def enable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Webhook/enable',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def disable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Webhook/disable',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Webhook/delete',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Webhook/get',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.GetWebhookRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Webhook/list',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookQuery.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhooksInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Webhook/stat',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_webhook__pb2.WebhookStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/stack_resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1spaceone/api/provisioning/v1/stack_resource.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xa5\x03\n\x1a\x43reateStackResourceRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x10\n\x08stack_id\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\x12\x15\n\rresource_name\x18\x04 \x01(\t\x12\x16\n\x0eterraform_code\x18\x05 \x01(\t\x12\x13\n\x0bvalid_value\x18\x06 \x03(\t\x12\x35\n\x14terraform_properties\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12$\n\x03tag\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\t \x01(\t\x12\x12\n\nupdated_at\x18\n \x01(\t\x12\x14\n\x0c\x61nsible_code\x18\x0b \x01(\t\x12\x0f\n\x07node_id\x18\x0c \x01(\r\x12\x11\n\timmutable\x18\r \x01(\t\x12\x33\n\x12\x61nsible_properties\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rresource_type\x18\x0f \x01(\t\"V\n\x14StackResourceRequest\x12\x19\n\x11stack_resource_id\x18\x01 \x01(\t\x12\x10\n\x08stack_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"U\n\x17GetStackResourceRequest\x12\x19\n\x11stack_resource_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xc0\x03\n\x1aUpdateStackResourceRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x19\n\x11stack_resource_id\x18\x02 \x01(\t\x12\x10\n\x08stack_id\x18\x03 \x01(\t\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\x12\x13\n\x0bvalid_value\x18\x07 \x03(\t\x12\x35\n\x14terraform_properties\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12$\n\x03tag\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\n \x01(\t\x12\x12\n\nupdated_at\x18\x0b \x01(\t\x12\x14\n\x0c\x61nsible_code\x18\x0c \x01(\t\x12\x0f\n\x07node_id\x18\r \x01(\r\x12\x11\n\timmutable\x18\x0e \x01(\t\x12\x33\n\x12\x61nsible_properties\x18\x0f \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rresource_type\x18\x10 \x01(\t\"\xd2\x01\n\x12StackResourceQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x19\n\x11stack_resource_id\x18\x02 \x01(\t\x12\x10\n\x08stack_id\x18\x03 \x01(\t\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12$\n\x03tag\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x07 \x01(\t\"a\n\x16StackResourceStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\xdf\x03\n\x11StackResourceInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x19\n\x11stack_resource_id\x18\x02 \x01(\t\x12\x10\n\x08stack_id\x18\x03 \x01(\t\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\x12\x13\n\x0bvalid_value\x18\x07 \x03(\t\x12\x35\n\x14terraform_properties\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12$\n\x03tag\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\n \x01(\t\x12\x12\n\nupdated_at\x18\x0b \x01(\t\x12\x14\n\x0c\x61nsible_code\x18\x0c \x01(\t\x12\x12\n\ncreated_by\x18\r \x01(\t\x12\x12\n\nupdated_by\x18\x0e \x01(\t\x12\x0f\n\x07node_id\x18\x0f \x01(\r\x12\x11\n\timmutable\x18\x10 \x01(\t\x12\x33\n\x12\x61nsible_properties\x18\x11 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rresource_type\x18\x12 \x01(\t\"k\n\x12StackResourcesInfo\x12@\n\x07results\x18\x01 \x03(\x0b\x32/.spaceone.api.provisioning.v1.StackResourceInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\xa1\x08\n\rStackResource\x12\xab\x01\n\x15\x63reate_stack_resource\x12\x38.spaceone.api.provisioning.v1.CreateStackResourceRequest\x1a/.spaceone.api.provisioning.v1.StackResourceInfo\"\'\x82\xd3\xe4\x93\x02!\"\x1f/provisioning/v1/stack-resource\x12\xce\x01\n\x13get_stack_resources\x12\x30.spaceone.api.provisioning.v1.StackResourceQuery\x1a\x30.spaceone.api.provisioning.v1.StackResourcesInfo\"S\x82\xd3\xe4\x93\x02M\x12 /provisioning/v1/stack-resourcesZ)\"\'/provisioning/v1/stack-resources/search\x12\xb9\x01\n\x12get_stack_resource\x12\x35.spaceone.api.provisioning.v1.GetStackResourceRequest\x1a/.spaceone.api.provisioning.v1.StackResourceInfo\";\x82\xd3\xe4\x93\x02\x35\x12\x33/provisioning/v1/stack-resource/{stack_resource_id}\x12\xab\x01\n\x15update_stack_resource\x12\x38.spaceone.api.provisioning.v1.UpdateStackResourceRequest\x1a/.spaceone.api.provisioning.v1.StackResourceInfo\"\'\x82\xd3\xe4\x93\x02!\x1a\x1f/provisioning/v1/stack-resource\x12\xa0\x01\n\x15\x64\x65lete_stack_resource\x12\x32.spaceone.api.provisioning.v1.StackResourceRequest\x1a\x16.google.protobuf.Empty\";\x82\xd3\xe4\x93\x02\x35*3/provisioning/v1/stack-resource/{stack_resource_id}\x12\x83\x01\n\x04stat\x12\x34.spaceone.api.provisioning.v1.StackResourceStatQuery\x1a\x17.google.protobuf.Struct\",\x82\xd3\xe4\x93\x02&\"$/provisioning/v1/stack-resource/statb\x06proto3')



_CREATESTACKRESOURCEREQUEST = DESCRIPTOR.message_types_by_name['CreateStackResourceRequest']
_STACKRESOURCEREQUEST = DESCRIPTOR.message_types_by_name['StackResourceRequest']
_GETSTACKRESOURCEREQUEST = DESCRIPTOR.message_types_by_name['GetStackResourceRequest']
_UPDATESTACKRESOURCEREQUEST = DESCRIPTOR.message_types_by_name['UpdateStackResourceRequest']
_STACKRESOURCEQUERY = DESCRIPTOR.message_types_by_name['StackResourceQuery']
_STACKRESOURCESTATQUERY = DESCRIPTOR.message_types_by_name['StackResourceStatQuery']
_STACKRESOURCEINFO = DESCRIPTOR.message_types_by_name['StackResourceInfo']
_STACKRESOURCESINFO = DESCRIPTOR.message_types_by_name['StackResourcesInfo']
CreateStackResourceRequest = _reflection.GeneratedProtocolMessageType('CreateStackResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTACKRESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CreateStackResourceRequest)
  })
_sym_db.RegisterMessage(CreateStackResourceRequest)

StackResourceRequest = _reflection.GeneratedProtocolMessageType('StackResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _STACKRESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackResourceRequest)
  })
_sym_db.RegisterMessage(StackResourceRequest)

GetStackResourceRequest = _reflection.GeneratedProtocolMessageType('GetStackResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTACKRESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.GetStackResourceRequest)
  })
_sym_db.RegisterMessage(GetStackResourceRequest)

UpdateStackResourceRequest = _reflection.GeneratedProtocolMessageType('UpdateStackResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTACKRESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.UpdateStackResourceRequest)
  })
_sym_db.RegisterMessage(UpdateStackResourceRequest)

StackResourceQuery = _reflection.GeneratedProtocolMessageType('StackResourceQuery', (_message.Message,), {
  'DESCRIPTOR' : _STACKRESOURCEQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackResourceQuery)
  })
_sym_db.RegisterMessage(StackResourceQuery)

StackResourceStatQuery = _reflection.GeneratedProtocolMessageType('StackResourceStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _STACKRESOURCESTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackResourceStatQuery)
  })
_sym_db.RegisterMessage(StackResourceStatQuery)

StackResourceInfo = _reflection.GeneratedProtocolMessageType('StackResourceInfo', (_message.Message,), {
  'DESCRIPTOR' : _STACKRESOURCEINFO,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackResourceInfo)
  })
_sym_db.RegisterMessage(StackResourceInfo)

StackResourcesInfo = _reflection.GeneratedProtocolMessageType('StackResourcesInfo', (_message.Message,), {
  'DESCRIPTOR' : _STACKRESOURCESINFO,
  '__module__' : 'spaceone.api.provisioning.v1.stack_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.StackResourcesInfo)
  })
_sym_db.RegisterMessage(StackResourcesInfo)

_STACKRESOURCE = DESCRIPTOR.services_by_name['StackResource']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STACKRESOURCE.methods_by_name['create_stack_resource']._options = None
  _STACKRESOURCE.methods_by_name['create_stack_resource']._serialized_options = b'\202\323\344\223\002!\"\037/provisioning/v1/stack-resource'
  _STACKRESOURCE.methods_by_name['get_stack_resources']._options = None
  _STACKRESOURCE.methods_by_name['get_stack_resources']._serialized_options = b'\202\323\344\223\002M\022 /provisioning/v1/stack-resourcesZ)\"\'/provisioning/v1/stack-resources/search'
  _STACKRESOURCE.methods_by_name['get_stack_resource']._options = None
  _STACKRESOURCE.methods_by_name['get_stack_resource']._serialized_options = b'\202\323\344\223\0025\0223/provisioning/v1/stack-resource/{stack_resource_id}'
  _STACKRESOURCE.methods_by_name['update_stack_resource']._options = None
  _STACKRESOURCE.methods_by_name['update_stack_resource']._serialized_options = b'\202\323\344\223\002!\032\037/provisioning/v1/stack-resource'
  _STACKRESOURCE.methods_by_name['delete_stack_resource']._options = None
  _STACKRESOURCE.methods_by_name['delete_stack_resource']._serialized_options = b'\202\323\344\223\0025*3/provisioning/v1/stack-resource/{stack_resource_id}'
  _STACKRESOURCE.methods_by_name['stat']._options = None
  _STACKRESOURCE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002&\"$/provisioning/v1/stack-resource/stat'
  _CREATESTACKRESOURCEREQUEST._serialized_start=207
  _CREATESTACKRESOURCEREQUEST._serialized_end=628
  _STACKRESOURCEREQUEST._serialized_start=630
  _STACKRESOURCEREQUEST._serialized_end=716
  _GETSTACKRESOURCEREQUEST._serialized_start=718
  _GETSTACKRESOURCEREQUEST._serialized_end=803
  _UPDATESTACKRESOURCEREQUEST._serialized_start=806
  _UPDATESTACKRESOURCEREQUEST._serialized_end=1254
  _STACKRESOURCEQUERY._serialized_start=1257
  _STACKRESOURCEQUERY._serialized_end=1467
  _STACKRESOURCESTATQUERY._serialized_start=1469
  _STACKRESOURCESTATQUERY._serialized_end=1566
  _STACKRESOURCEINFO._serialized_start=1569
  _STACKRESOURCEINFO._serialized_end=2048
  _STACKRESOURCESINFO._serialized_start=2050
  _STACKRESOURCESINFO._serialized_end=2157
  _STACKRESOURCE._serialized_start=2160
  _STACKRESOURCE._serialized_end=3217
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/board/v1/post.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n spaceone/api/board/v1/post.proto\x12\x15spaceone.api.board.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xb4\x01\n\x11\x43reatePostRequest\x12\x10\n\x08\x62oard_id\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x10\n\x08\x63ontents\x18\x04 \x01(\t\x12(\n\x07options\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06writer\x18\x06 \x01(\t\x12\r\n\x05\x66iles\x18\x07 \x03(\t\x12\x11\n\tdomain_id\x18\n \x01(\t\"\xc5\x01\n\x11UpdatePostRequest\x12\x10\n\x08\x62oard_id\x18\x01 \x01(\t\x12\x0f\n\x07post_id\x18\x02 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x10\n\x08\x63ontents\x18\x05 \x01(\t\x12(\n\x07options\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06writer\x18\x07 \x01(\t\x12\r\n\x05\x66iles\x18\x08 \x03(\t\x12\x11\n\tdomain_id\x18\n \x01(\t\"O\n\x17SendNotificationRequest\x12\x10\n\x08\x62oard_id\x18\x01 \x01(\t\x12\x0f\n\x07post_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"C\n\x0bPostRequest\x12\x10\n\x08\x62oard_id\x18\x01 \x01(\t\x12\x0f\n\x07post_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"T\n\x0eGetPostRequest\x12\x10\n\x08\x62oard_id\x18\x01 \x01(\t\x12\x0f\n\x07post_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\x12\x11\n\tdomain_id\x18\x07 \x01(\t\"\x98\x03\n\tPostQuery\x12\x10\n\x08\x62oard_id\x18\x01 \x01(\t\x12\x0f\n\x07post_id\x18\x02 \x01(\t\x12<\n\tpost_type\x18\x03 \x01(\x0e\x32).spaceone.api.board.v1.PostQuery.PostType\x12\x10\n\x08\x63\x61tegory\x18\x04 \x01(\t\x12\x0e\n\x06writer\x18\x05 \x01(\t\x12\x35\n\x05scope\x18\x06 \x01(\x0e\x32&.spaceone.api.board.v1.PostQuery.Scope\x12\x0f\n\x07user_id\x18\x07 \x01(\t\x12\x16\n\x0euser_domain_id\x18\x08 \x01(\t\x12\x11\n\tdomain_id\x18\t \x01(\t\x12*\n\x05query\x18\n \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\"/\n\x05Scope\x12\x0e\n\nSCOPE_NONE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\n\n\x06\x44OMAIN\x10\x02\"8\n\x08PostType\x12\x12\n\x0ePOST_TYPE_NONE\x10\x00\x12\n\n\x06SYSTEM\x10\x01\x12\x0c\n\x08INTERNAL\x10\x02\"X\n\rPostStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x9b\x04\n\x08PostInfo\x12\x10\n\x08\x62oard_id\x18\x01 \x01(\t\x12\x0f\n\x07post_id\x18\x02 \x01(\t\x12;\n\tpost_type\x18\x03 \x01(\x0e\x32(.spaceone.api.board.v1.PostInfo.PostType\x12\x10\n\x08\x63\x61tegory\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12\x10\n\x08\x63ontents\x18\x06 \x01(\t\x12(\n\x07options\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nview_count\x18\x08 \x01(\x05\x12\x0e\n\x06writer\x18\t \x01(\t\x12\x34\n\x05scope\x18\n \x01(\x0e\x32%.spaceone.api.board.v1.PostInfo.Scope\x12)\n\x05\x66iles\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x11\n\tdomain_id\x18\x15 \x01(\t\x12\x0f\n\x07user_id\x18\x16 \x01(\t\x12\x16\n\x0euser_domain_id\x18\x17 \x01(\t\x12\x12\n\ncreated_at\x18\x1f \x01(\t\x12\x12\n\nupdated_at\x18  \x01(\t\"/\n\x05Scope\x12\x0e\n\nSCOPE_NONE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\n\n\x06\x44OMAIN\x10\x02\"8\n\x08PostType\x12\x12\n\x0ePOST_TYPE_NONE\x10\x00\x12\n\n\x06SYSTEM\x10\x01\x12\x0c\n\x08INTERNAL\x10\x02\"R\n\tPostsInfo\x12\x30\n\x07results\x18\x01 \x03(\x0b\x32\x1f.spaceone.api.board.v1.PostInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\xc5\x07\n\x04Post\x12}\n\x06\x63reate\x12(.spaceone.api.board.v1.CreatePostRequest\x1a\x1f.spaceone.api.board.v1.PostInfo\"(\x82\xd3\xe4\x93\x02\"\" /board/v1/board/{board_id}/posts\x12\x86\x01\n\x06update\x12(.spaceone.api.board.v1.UpdatePostRequest\x1a\x1f.spaceone.api.board.v1.PostInfo\"1\x82\xd3\xe4\x93\x02+\x1a)/board/v1/board/{board_id}/post/{post_id}\x12\xa0\x01\n\x11send_notification\x12..spaceone.api.board.v1.SendNotificationRequest\x1a\x16.google.protobuf.Empty\"C\x82\xd3\xe4\x93\x02=\";/board/v1/board/{board_id}/post/{post_id}/send-notification\x12w\n\x06\x64\x65lete\x12\".spaceone.api.board.v1.PostRequest\x1a\x16.google.protobuf.Empty\"1\x82\xd3\xe4\x93\x02+*)/board/v1/board/{board_id}/post/{post_id}\x12\x80\x01\n\x03get\x12%.spaceone.api.board.v1.GetPostRequest\x1a\x1f.spaceone.api.board.v1.PostInfo\"1\x82\xd3\xe4\x93\x02+\x12)/board/v1/board/{board_id}/post/{post_id}\x12\x9f\x01\n\x04list\x12 .spaceone.api.board.v1.PostQuery\x1a .spaceone.api.board.v1.PostsInfo\"S\x82\xd3\xe4\x93\x02M\x12 /board/v1/board/{board_id}/postsZ)\"\'/board/v1/board/{board_id}/posts/search\x12t\n\x04stat\x12$.spaceone.api.board.v1.PostStatQuery\x1a\x17.google.protobuf.Struct\"-\x82\xd3\xe4\x93\x02\'\"%/board/v1/board/{board_id}/posts/statb\x06proto3')



_CREATEPOSTREQUEST = DESCRIPTOR.message_types_by_name['CreatePostRequest']
_UPDATEPOSTREQUEST = DESCRIPTOR.message_types_by_name['UpdatePostRequest']
_SENDNOTIFICATIONREQUEST = DESCRIPTOR.message_types_by_name['SendNotificationRequest']
_POSTREQUEST = DESCRIPTOR.message_types_by_name['PostRequest']
_GETPOSTREQUEST = DESCRIPTOR.message_types_by_name['GetPostRequest']
_POSTQUERY = DESCRIPTOR.message_types_by_name['PostQuery']
_POSTSTATQUERY = DESCRIPTOR.message_types_by_name['PostStatQuery']
_POSTINFO = DESCRIPTOR.message_types_by_name['PostInfo']
_POSTSINFO = DESCRIPTOR.message_types_by_name['PostsInfo']
_POSTQUERY_SCOPE = _POSTQUERY.enum_types_by_name['Scope']
_POSTQUERY_POSTTYPE = _POSTQUERY.enum_types_by_name['PostType']
_POSTINFO_SCOPE = _POSTINFO.enum_types_by_name['Scope']
_POSTINFO_POSTTYPE = _POSTINFO.enum_types_by_name['PostType']
CreatePostRequest = _reflection.GeneratedProtocolMessageType('CreatePostRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPOSTREQUEST,
  '__module__' : 'spaceone.api.board.v1.post_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.board.v1.CreatePostRequest)
  })
_sym_db.RegisterMessage(CreatePostRequest)

UpdatePostRequest = _reflection.GeneratedProtocolMessageType('UpdatePostRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPOSTREQUEST,
  '__module__' : 'spaceone.api.board.v1.post_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.board.v1.UpdatePostRequest)
  })
_sym_db.RegisterMessage(UpdatePostRequest)

SendNotificationRequest = _reflection.GeneratedProtocolMessageType('SendNotificationRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDNOTIFICATIONREQUEST,
  '__module__' : 'spaceone.api.board.v1.post_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.board.v1.SendNotificationRequest)
  })
_sym_db.RegisterMessage(SendNotificationRequest)

PostRequest = _reflection.GeneratedProtocolMessageType('PostRequest', (_message.Message,), {
  'DESCRIPTOR' : _POSTREQUEST,
  '__module__' : 'spaceone.api.board.v1.post_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.board.v1.PostRequest)
  })
_sym_db.RegisterMessage(PostRequest)

GetPostRequest = _reflection.GeneratedProtocolMessageType('GetPostRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPOSTREQUEST,
  '__module__' : 'spaceone.api.board.v1.post_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.board.v1.GetPostRequest)
  })
_sym_db.RegisterMessage(GetPostRequest)

PostQuery = _reflection.GeneratedProtocolMessageType('PostQuery', (_message.Message,), {
  'DESCRIPTOR' : _POSTQUERY,
  '__module__' : 'spaceone.api.board.v1.post_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.board.v1.PostQuery)
  })
_sym_db.RegisterMessage(PostQuery)

PostStatQuery = _reflection.GeneratedProtocolMessageType('PostStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _POSTSTATQUERY,
  '__module__' : 'spaceone.api.board.v1.post_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.board.v1.PostStatQuery)
  })
_sym_db.RegisterMessage(PostStatQuery)

PostInfo = _reflection.GeneratedProtocolMessageType('PostInfo', (_message.Message,), {
  'DESCRIPTOR' : _POSTINFO,
  '__module__' : 'spaceone.api.board.v1.post_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.board.v1.PostInfo)
  })
_sym_db.RegisterMessage(PostInfo)

PostsInfo = _reflection.GeneratedProtocolMessageType('PostsInfo', (_message.Message,), {
  'DESCRIPTOR' : _POSTSINFO,
  '__module__' : 'spaceone.api.board.v1.post_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.board.v1.PostsInfo)
  })
_sym_db.RegisterMessage(PostsInfo)

_POST = DESCRIPTOR.services_by_name['Post']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _POST.methods_by_name['create']._options = None
  _POST.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\"\" /board/v1/board/{board_id}/posts'
  _POST.methods_by_name['update']._options = None
  _POST.methods_by_name['update']._serialized_options = b'\202\323\344\223\002+\032)/board/v1/board/{board_id}/post/{post_id}'
  _POST.methods_by_name['send_notification']._options = None
  _POST.methods_by_name['send_notification']._serialized_options = b'\202\323\344\223\002=\";/board/v1/board/{board_id}/post/{post_id}/send-notification'
  _POST.methods_by_name['delete']._options = None
  _POST.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002+*)/board/v1/board/{board_id}/post/{post_id}'
  _POST.methods_by_name['get']._options = None
  _POST.methods_by_name['get']._serialized_options = b'\202\323\344\223\002+\022)/board/v1/board/{board_id}/post/{post_id}'
  _POST.methods_by_name['list']._options = None
  _POST.methods_by_name['list']._serialized_options = b'\202\323\344\223\002M\022 /board/v1/board/{board_id}/postsZ)\"\'/board/v1/board/{board_id}/posts/search'
  _POST.methods_by_name['stat']._options = None
  _POST.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\'\"%/board/v1/board/{board_id}/posts/stat'
  _CREATEPOSTREQUEST._serialized_start=183
  _CREATEPOSTREQUEST._serialized_end=363
  _UPDATEPOSTREQUEST._serialized_start=366
  _UPDATEPOSTREQUEST._serialized_end=563
  _SENDNOTIFICATIONREQUEST._serialized_start=565
  _SENDNOTIFICATIONREQUEST._serialized_end=644
  _POSTREQUEST._serialized_start=646
  _POSTREQUEST._serialized_end=713
  _GETPOSTREQUEST._serialized_start=715
  _GETPOSTREQUEST._serialized_end=799
  _POSTQUERY._serialized_start=802
  _POSTQUERY._serialized_end=1210
  _POSTQUERY_SCOPE._serialized_start=1105
  _POSTQUERY_SCOPE._serialized_end=1152
  _POSTQUERY_POSTTYPE._serialized_start=1154
  _POSTQUERY_POSTTYPE._serialized_end=1210
  _POSTSTATQUERY._serialized_start=1212
  _POSTSTATQUERY._serialized_end=1300
  _POSTINFO._serialized_start=1303
  _POSTINFO._serialized_end=1842
  _POSTINFO_SCOPE._serialized_start=1105
  _POSTINFO_SCOPE._serialized_end=1152
  _POSTINFO_POSTTYPE._serialized_start=1154
  _POSTINFO_POSTTYPE._serialized_end=1210
  _POSTSINFO._serialized_start=1844
  _POSTSINFO._serialized_end=1926
  _POST._serialized_start=1929
  _POST._serialized_end=2894
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/notification/plugin/notification.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3spaceone/api/notification/plugin/notification.proto\x12 spaceone.api.notification.plugin\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x8c\x03\n\x15PluginDispatchRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12(\n\x07message\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x63\n\x11notification_type\x18\x03 \x01(\x0e\x32H.spaceone.api.notification.plugin.PluginDispatchRequest.NotificationType\x12,\n\x0bsecret_data\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12-\n\x0c\x63hannel_data\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"]\n\x10NotificationType\x12\x1a\n\x16NOTIFICATION_TYPE_NONE\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0b\n\x07SUCCESS\x10\x03\x12\x0b\n\x07WARNING\x10\x04\x32m\n\x0cNotification\x12]\n\x08\x64ispatch\x12\x37.spaceone.api.notification.plugin.PluginDispatchRequest\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3')



_PLUGINDISPATCHREQUEST = DESCRIPTOR.message_types_by_name['PluginDispatchRequest']
_PLUGINDISPATCHREQUEST_NOTIFICATIONTYPE = _PLUGINDISPATCHREQUEST.enum_types_by_name['NotificationType']
PluginDispatchRequest = _reflection.GeneratedProtocolMessageType('PluginDispatchRequest', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINDISPATCHREQUEST,
  '__module__' : 'spaceone.api.notification.plugin.notification_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.plugin.PluginDispatchRequest)
  })
_sym_db.RegisterMessage(PluginDispatchRequest)

_NOTIFICATION = DESCRIPTOR.services_by_name['Notification']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PLUGINDISPATCHREQUEST._serialized_start=149
  _PLUGINDISPATCHREQUEST._serialized_end=545
  _PLUGINDISPATCHREQUEST_NOTIFICATIONTYPE._serialized_start=452
  _PLUGINDISPATCHREQUEST_NOTIFICATIONTYPE._serialized_end=545
  _NOTIFICATION._serialized_start=547
  _NOTIFICATION._serialized_end=656
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.inventory.v1 import job_task_pb2 as spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2


class JobTaskStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.delete = channel.unary_unary(
                '/spaceone.api.inventory.v1.JobTask/delete',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2.JobTaskRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.inventory.v1.JobTask/get',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2.GetJobTaskRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2.JobTaskInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.inventory.v1.JobTask/list',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2.JobTaskQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2.JobTasksInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.inventory.v1.JobTask/stat',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2.JobTaskStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class JobTaskServicer(object):
    """Missing associated documentation comment in .proto file."""

    def delete(self, request, context):
        """
        desc: Deletes a specific JobTask. You must specify the `job_task_id` of the JobTask to delete.
        request_example: >-
        {
        "job_task_id": "job-task-123456789012",
        "domain_id": "domain-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific JobTask. Prints detailed information about the JobTask, including its state, updated or failure counts, and error log.
        request_example: >-
        {
        "job_task_id": "job-task-123456789012",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "job_task_id": "job-task-123456789012",
        "status": "FAILURE",
        "updated_count": 199,
        "failure_count": 1,
        "errors": [
        {
        "error_code": "ERROR_PLUGIN",
        "message": "{\"tags\": [\"Could not interpret the value as a list\"]}",
        "additional": {
        "domain_id": "domain-123456789012",
        "resource_id": "eventarc-us-central1-function",
        "resource_type": "inventory.CloudService",
        "cloud_service_group": "Pub/Sub",
        "cloud_service_type": "Subscription",
        "provider": "google_cloud"
        }
        }
        ],
        "job_id": "job-123456789012",
        "secret_id": "secret-123456789012",
        "provider": "google_cloud",
        "service_account_id": "sa-123456789012",
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T11:00:02.588Z",
        "started_at": "2022-01-01T11:00:02.819Z",
        "finished_at": "2022-01-01T11:00:34.398Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all JobTasks in a specific Job. You can use a query to get a filtered list of JobTasks.
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "job_task_id": "job_task-69b301d0fbfc",
        "status": "SUCCESS",
        "updated_count": 55,
        "job_id": "job-587a3d3b4db3",
        "secret_id": "secret-957e407bfc15",
        "provider": "aws",
        "service_account_id": "sa-a41ff4765671",
        "project_id": "project-77dffd3f7cd3",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-17T08:00:00.680Z",
        "started_at": "2022-06-17T08:00:00.914Z",
        "finished_at": "2022-06-17T08:05:48.933Z"
        },
        {
        "job_task_id": "job_task-c5077338cf23",
        "status": "SUCCESS",
        "updated_count": 1921,
        "job_id": "job-587a3d3b4db3",
        "secret_id": "secret-1cd7417c1889",
        "provider": "aws",
        "service_account_id": "sa-5e186fcc7c91",
        "project_id": "project-18655561c535",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-17T08:00:00.582Z",
        "started_at": "2022-06-17T08:00:00.814Z",
        "finished_at": "2022-06-17T08:07:31.995Z"
        }
        ],
        "total_count": 4839
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_JobTaskServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2.JobTaskRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2.GetJobTaskRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2.JobTaskInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2.JobTaskQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2.JobTasksInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2.JobTaskStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.inventory.v1.JobTask', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class JobTask(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.JobTask/delete',
            spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2.JobTaskRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.JobTask/get',
            spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2.GetJobTaskRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2.JobTaskInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.JobTask/list',
            spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2.JobTaskQuery.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2.JobTasksInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.JobTask/stat',
            spaceone_dot_api_dot_inventory_dot_v1_dot_job__task__pb2.JobTaskStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/plugin/cost.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,spaceone/api/cost_analysis/plugin/cost.proto\x12!spaceone.api.cost_analysis.plugin\x1a\x1cgoogle/protobuf/struct.proto\"\xba\x01\n\x0eGetDataRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12-\n\x0ctask_options\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x05 \x01(\t\"\xcd\x03\n\x08\x43ostInfo\x12\x0c\n\x04\x63ost\x18\x01 \x01(\x01\x12\x10\n\x08\x63urrency\x18\x02 \x01(\t\x12\x16\n\x0eusage_quantity\x18\x03 \x01(\x01\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\x13\n\x0bregion_code\x18\x05 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x06 \x01(\t\x12\x0f\n\x07product\x18\x07 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x08 \x01(\t\x12\x12\n\nusage_type\x18\t \x01(\t\x12\x16\n\x0eresource_group\x18\n \x01(\t\x12\x10\n\x08resource\x18\x0b \x01(\t\x12%\n\x04tags\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x30\n\x0f\x61\x64\x64itional_info\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tbilled_at\x18\x0e \x01(\t\x12\x11\n\tcost_type\x18\x0f \x01(\t\x12\x14\n\x0cproduct_code\x18\x10 \x01(\t\x12\x1d\n\x15original_product_code\x18\x11 \x01(\t\x12\x13\n\x0bproduct_sku\x18\x12 \x01(\t\x12\x15\n\rexchange_rate\x18\x13 \x01(\x01\x12\x10\n\x08usd_cost\x18\x14 \x01(\x01\"I\n\tCostsInfo\x12<\n\x07results\x18\x01 \x03(\x0b\x32+.spaceone.api.cost_analysis.plugin.CostInfo2w\n\x04\x43ost\x12o\n\x08get_data\x12\x31.spaceone.api.cost_analysis.plugin.GetDataRequest\x1a,.spaceone.api.cost_analysis.plugin.CostsInfo\"\x00\x30\x01\x62\x06proto3')



_GETDATAREQUEST = DESCRIPTOR.message_types_by_name['GetDataRequest']
_COSTINFO = DESCRIPTOR.message_types_by_name['CostInfo']
_COSTSINFO = DESCRIPTOR.message_types_by_name['CostsInfo']
GetDataRequest = _reflection.GeneratedProtocolMessageType('GetDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.plugin.cost_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.plugin.GetDataRequest)
  })
_sym_db.RegisterMessage(GetDataRequest)

CostInfo = _reflection.GeneratedProtocolMessageType('CostInfo', (_message.Message,), {
  'DESCRIPTOR' : _COSTINFO,
  '__module__' : 'spaceone.api.cost_analysis.plugin.cost_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.plugin.CostInfo)
  })
_sym_db.RegisterMessage(CostInfo)

CostsInfo = _reflection.GeneratedProtocolMessageType('CostsInfo', (_message.Message,), {
  'DESCRIPTOR' : _COSTSINFO,
  '__module__' : 'spaceone.api.cost_analysis.plugin.cost_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.plugin.CostsInfo)
  })
_sym_db.RegisterMessage(CostsInfo)

_COST = DESCRIPTOR.services_by_name['Cost']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETDATAREQUEST._serialized_start=114
  _GETDATAREQUEST._serialized_end=300
  _COSTINFO._serialized_start=303
  _COSTINFO._serialized_end=764
  _COSTSINFO._serialized_start=766
  _COSTSINFO._serialized_end=839
  _COST._serialized_start=841
  _COST._serialized_end=960
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.repository.v1 import policy_pb2 as spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2


class PolicyStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.repository.v1.Policy/create',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.CreatePolicyRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PolicyInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.repository.v1.Policy/update',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.UpdatePolicyRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PolicyInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.repository.v1.Policy/delete',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PolicyRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.repository.v1.Policy/get',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.GetRepositoryPolicyRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PolicyInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.repository.v1.Policy/list',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PolicyQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PoliciesInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.repository.v1.Policy/stat',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PolicyStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class PolicyServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new Policy. The parameter `policy_id`, an identifier of Policy resources, can only include lowercase alphabets, numbers, and hyphens(-). The parameter `permissions` is a list type data describing page access permissions.
        request_example: >-
        {
        "policy_id": "policy-custom-full-acess",
        "name": "Full Access",
        "permissions": ["*"],
        "labels": [],
        "tags": {},
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "policy_id": "policy-custom-full-acess",
        "name": "Full Access",
        "state": "ENABLED",
        "permissions": [
        "*"
        ],
        "labels": [],
        "tags": {},
        "repository_info": {
        "repository_id": "repo-123456789012",
        "name": "Local",
        "repository_type": "local"
        },
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T06:45:04.582Z",
        "updated_at": "2022-01-01T06:45:04.582Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific Policy. You can make changes in Policy settings, including `name`, `labels`, `tags`, and `permissions`. The parameter `policy_id` cannot be updated.
        request_example: >-
        {
        "policy_id": "policy-custom-full-acess",
        "name": "Full Access",
        "permissions": ["*"],
        "labels": [],
        "tags": {},
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "policy_id": "policy-custom-full-acess",
        "name": "Full Access",
        "state": "ENABLED",
        "permissions": [
        "*"
        ],
        "labels": [],
        "tags": {},
        "repository_info": {
        "repository_id": "repo-123456789012",
        "name": "Local",
        "repository_type": "local"
        },
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T06:45:04.582Z",
        "updated_at": "2022-01-01T06:45:04.582Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific Policy. You must specify the `policy_id` of the Policy to delete, as the `policy_id` is an identifier of Policy resources.
        request_example: >-
        {
        "policy_id": "policy-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Policy. You must specify the `policy_id` of the Policy to get, as the `policy_id` is an identifier of Policy resources. You can use the parameter `repository_id` to limit the scope of the method to a specific Repository.
        request_example: >-
        {
        "policy_id": "policy-123456789012",
        "repository_id": "repo-123456789012"
        }
        response_example: >-
        {
        "policy_id": "policy-123456789012",
        "name": "Full Access",
        "state": "ENABLED",
        "permissions": [
        "*"
        ],
        "labels": [],
        "tags": {},
        "repository_info": {
        "repository_id": "repo-123456789012",
        "name": "Local",
        "repository_type": "local"
        },
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T15:42:50.943Z",
        "updated_at": "2022-01-01T15:42:50.943Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Policies in a specific Repository. The parameter `repository_id` is used as an identifier of a Repository to get its list of Policies. You can use a query to get a filtered list of Policies.
        request_example: >-
        {
        "query": {},
        "repository_id": "repo-123456789012"
        }
        response_example: >-
        {
        "results": [
        {
        "policy_id": "policy-123456789012",
        "name": "Full Access",
        "state": "ENABLED",
        "permissions": [
        "*"
        ],
        "labels": [],
        "tags": {},
        "repository_info": {
        "repository_id": "repo-123456789012",
        "name": "Local",
        "repository_type": "local"
        },
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T15:42:50.943Z",
        "updated_at": "2022-01-01T15:42:50.943Z"
        },
        {
        "policy_id": "policy-987654321098",
        "name": "Identity Admin",
        "state": "ENABLED",
        "permissions": [
        "identity.*"
        ],
        "labels": [],
        "tags": {},
        "repository_info": {
        "repository_id": "repo-123456789012",
        "name": "Local",
        "repository_type": "local"
        },
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T08:08:14.756Z",
        "updated_at": "2022-01-01T08:08:14.756Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PolicyServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.CreatePolicyRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PolicyInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.UpdatePolicyRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PolicyInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PolicyRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.GetRepositoryPolicyRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PolicyInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PolicyQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PoliciesInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PolicyStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.repository.v1.Policy', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Policy(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Policy/create',
            spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.CreatePolicyRequest.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PolicyInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Policy/update',
            spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.UpdatePolicyRequest.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PolicyInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Policy/delete',
            spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PolicyRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Policy/get',
            spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.GetRepositoryPolicyRequest.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PolicyInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Policy/list',
            spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PolicyQuery.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PoliciesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Policy/stat',
            spaceone_dot_api_dot_repository_dot_v1_dot_policy__pb2.PolicyStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/schedule.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,spaceone/api/cost_analysis/v1/schedule.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"K\n\tScheduled\x12\x0c\n\x04\x63ron\x18\x01 \x01(\t\x12\x10\n\x08interval\x18\x02 \x01(\x05\x12\x0f\n\x07minutes\x18\x03 \x03(\x05\x12\r\n\x05hours\x18\x04 \x03(\x05\"\xdd\x01\n\x15\x43reateScheduleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12:\n\x08schedule\x18\x03 \x01(\x0b\x32(.spaceone.api.cost_analysis.v1.Scheduled\x12(\n\x07options\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x16\n\x0e\x64\x61ta_source_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\"\xda\x01\n\x15UpdateScheduleRequest\x12\x13\n\x0bschedule_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12:\n\x08schedule\x18\x03 \x01(\x0b\x32(.spaceone.api.cost_analysis.v1.Scheduled\x12(\n\x07options\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"9\n\x0fScheduleRequest\x12\x13\n\x0bschedule_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"J\n\x12GetScheduleRequest\x12\x13\n\x0bschedule_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x98\x01\n\rScheduleQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x13\n\x0bschedule_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x16\n\x0e\x64\x61ta_source_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\x88\x03\n\x0cScheduleInfo\x12\x13\n\x0bschedule_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12@\n\x05state\x18\x03 \x01(\x0e\x32\x31.spaceone.api.cost_analysis.v1.ScheduleInfo.State\x12:\n\x08schedule\x18\x04 \x01(\x0b\x32(.spaceone.api.cost_analysis.v1.Scheduled\x12(\n\x07options\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x16\n\x0e\x64\x61ta_source_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\x12\x19\n\x11last_scheduled_at\x18\x16 \x01(\t\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"b\n\rSchedulesInfo\x12<\n\x07results\x18\x01 \x03(\x0b\x32+.spaceone.api.cost_analysis.v1.ScheduleInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\\\n\x11ScheduleStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xcd\t\n\x08Schedule\x12\x90\x01\n\x06\x63reate\x12\x34.spaceone.api.cost_analysis.v1.CreateScheduleRequest\x1a+.spaceone.api.cost_analysis.v1.ScheduleInfo\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/cost-analysis/v1/schedules\x12\x9d\x01\n\x06update\x12\x34.spaceone.api.cost_analysis.v1.UpdateScheduleRequest\x1a+.spaceone.api.cost_analysis.v1.ScheduleInfo\"0\x82\xd3\xe4\x93\x02*\x1a(/cost-analysis/v1/schedule/{schedule_id}\x12\x9e\x01\n\x06\x65nable\x12..spaceone.api.cost_analysis.v1.ScheduleRequest\x1a+.spaceone.api.cost_analysis.v1.ScheduleInfo\"7\x82\xd3\xe4\x93\x02\x31\x1a//cost-analysis/v1/schedule/{schedule_id}/enable\x12\xa0\x01\n\x07\x64isable\x12..spaceone.api.cost_analysis.v1.ScheduleRequest\x1a+.spaceone.api.cost_analysis.v1.ScheduleInfo\"8\x82\xd3\xe4\x93\x02\x32\x1a\x30/cost-analysis/v1/schedule/{schedule_id}/disable\x12\x82\x01\n\x06\x64\x65lete\x12..spaceone.api.cost_analysis.v1.ScheduleRequest\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02**(/cost-analysis/v1/schedule/{schedule_id}\x12\x97\x01\n\x03get\x12\x31.spaceone.api.cost_analysis.v1.GetScheduleRequest\x1a+.spaceone.api.cost_analysis.v1.ScheduleInfo\"0\x82\xd3\xe4\x93\x02*\x12(/cost-analysis/v1/schedule/{schedule_id}\x12\xad\x01\n\x04list\x12,.spaceone.api.cost_analysis.v1.ScheduleQuery\x1a,.spaceone.api.cost_analysis.v1.SchedulesInfo\"I\x82\xd3\xe4\x93\x02\x43\x12\x1b/cost-analysis/v1/schedulesZ$\"\"/cost-analysis/v1/schedules/search\x12{\n\x04stat\x12\x30.spaceone.api.cost_analysis.v1.ScheduleStatQuery\x1a\x17.google.protobuf.Struct\"(\x82\xd3\xe4\x93\x02\"\" /cost-analysis/v1/schedules/statb\x06proto3')



_SCHEDULED = DESCRIPTOR.message_types_by_name['Scheduled']
_CREATESCHEDULEREQUEST = DESCRIPTOR.message_types_by_name['CreateScheduleRequest']
_UPDATESCHEDULEREQUEST = DESCRIPTOR.message_types_by_name['UpdateScheduleRequest']
_SCHEDULEREQUEST = DESCRIPTOR.message_types_by_name['ScheduleRequest']
_GETSCHEDULEREQUEST = DESCRIPTOR.message_types_by_name['GetScheduleRequest']
_SCHEDULEQUERY = DESCRIPTOR.message_types_by_name['ScheduleQuery']
_SCHEDULEINFO = DESCRIPTOR.message_types_by_name['ScheduleInfo']
_SCHEDULESINFO = DESCRIPTOR.message_types_by_name['SchedulesInfo']
_SCHEDULESTATQUERY = DESCRIPTOR.message_types_by_name['ScheduleStatQuery']
_SCHEDULEINFO_STATE = _SCHEDULEINFO.enum_types_by_name['State']
Scheduled = _reflection.GeneratedProtocolMessageType('Scheduled', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULED,
  '__module__' : 'spaceone.api.cost_analysis.v1.schedule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.Scheduled)
  })
_sym_db.RegisterMessage(Scheduled)

CreateScheduleRequest = _reflection.GeneratedProtocolMessageType('CreateScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCHEDULEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.schedule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CreateScheduleRequest)
  })
_sym_db.RegisterMessage(CreateScheduleRequest)

UpdateScheduleRequest = _reflection.GeneratedProtocolMessageType('UpdateScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCHEDULEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.schedule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UpdateScheduleRequest)
  })
_sym_db.RegisterMessage(UpdateScheduleRequest)

ScheduleRequest = _reflection.GeneratedProtocolMessageType('ScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.schedule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.ScheduleRequest)
  })
_sym_db.RegisterMessage(ScheduleRequest)

GetScheduleRequest = _reflection.GeneratedProtocolMessageType('GetScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSCHEDULEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.schedule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.GetScheduleRequest)
  })
_sym_db.RegisterMessage(GetScheduleRequest)

ScheduleQuery = _reflection.GeneratedProtocolMessageType('ScheduleQuery', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.schedule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.ScheduleQuery)
  })
_sym_db.RegisterMessage(ScheduleQuery)

ScheduleInfo = _reflection.GeneratedProtocolMessageType('ScheduleInfo', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULEINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.schedule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.ScheduleInfo)
  })
_sym_db.RegisterMessage(ScheduleInfo)

SchedulesInfo = _reflection.GeneratedProtocolMessageType('SchedulesInfo', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULESINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.schedule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.SchedulesInfo)
  })
_sym_db.RegisterMessage(SchedulesInfo)

ScheduleStatQuery = _reflection.GeneratedProtocolMessageType('ScheduleStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULESTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.schedule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.ScheduleStatQuery)
  })
_sym_db.RegisterMessage(ScheduleStatQuery)

_SCHEDULE = DESCRIPTOR.services_by_name['Schedule']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SCHEDULE.methods_by_name['create']._options = None
  _SCHEDULE.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\035\"\033/cost-analysis/v1/schedules'
  _SCHEDULE.methods_by_name['update']._options = None
  _SCHEDULE.methods_by_name['update']._serialized_options = b'\202\323\344\223\002*\032(/cost-analysis/v1/schedule/{schedule_id}'
  _SCHEDULE.methods_by_name['enable']._options = None
  _SCHEDULE.methods_by_name['enable']._serialized_options = b'\202\323\344\223\0021\032//cost-analysis/v1/schedule/{schedule_id}/enable'
  _SCHEDULE.methods_by_name['disable']._options = None
  _SCHEDULE.methods_by_name['disable']._serialized_options = b'\202\323\344\223\0022\0320/cost-analysis/v1/schedule/{schedule_id}/disable'
  _SCHEDULE.methods_by_name['delete']._options = None
  _SCHEDULE.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002**(/cost-analysis/v1/schedule/{schedule_id}'
  _SCHEDULE.methods_by_name['get']._options = None
  _SCHEDULE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002*\022(/cost-analysis/v1/schedule/{schedule_id}'
  _SCHEDULE.methods_by_name['list']._options = None
  _SCHEDULE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002C\022\033/cost-analysis/v1/schedulesZ$\"\"/cost-analysis/v1/schedules/search'
  _SCHEDULE.methods_by_name['stat']._options = None
  _SCHEDULE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\"\" /cost-analysis/v1/schedules/stat'
  _SCHEDULED._serialized_start=202
  _SCHEDULED._serialized_end=277
  _CREATESCHEDULEREQUEST._serialized_start=280
  _CREATESCHEDULEREQUEST._serialized_end=501
  _UPDATESCHEDULEREQUEST._serialized_start=504
  _UPDATESCHEDULEREQUEST._serialized_end=722
  _SCHEDULEREQUEST._serialized_start=724
  _SCHEDULEREQUEST._serialized_end=781
  _GETSCHEDULEREQUEST._serialized_start=783
  _GETSCHEDULEREQUEST._serialized_end=857
  _SCHEDULEQUERY._serialized_start=860
  _SCHEDULEQUERY._serialized_end=1012
  _SCHEDULEINFO._serialized_start=1015
  _SCHEDULEINFO._serialized_end=1407
  _SCHEDULEINFO_STATE._serialized_start=1363
  _SCHEDULEINFO_STATE._serialized_end=1407
  _SCHEDULESINFO._serialized_start=1409
  _SCHEDULESINFO._serialized_end=1507
  _SCHEDULESTATQUERY._serialized_start=1509
  _SCHEDULESTATQUERY._serialized_end=1601
  _SCHEDULE._serialized_start=1604
  _SCHEDULE._serialized_end=2833
# @@protoc_insertion_point(module_scope)
